@@ -80,6 +80,8 @@ define!({
 
         Space(SpaceValues),
 
+        Comma(CommaValues),
+
         Brace(BraceValue),
 
         Lazy(Tokens),
@@ -94,6 +96,11 @@ define!({
         pub values: Vec<Value>,
     }
 
+    pub struct CommaValues {
+        pub span: Span,
+        pub values: Vec<Value>,
+    }
+
     pub struct BinValue {
         pub span: Span,
 
@@ -187,7 +194,7 @@ define!({
 
         Attr(AttrSelector),
 
-        PseudoClass(PseudoSelector),
+        Pseudo(PseudoSelector),
 
         At(AtSelector),
     }
@@ -196,7 +203,7 @@ define!({
         pub span: Span,
         pub name: NamespacedName,
         pub op: Option<AttrSelectorOp>,
-        pub value: Option<Text>,
+        pub value: Option<Str>,
         pub modifier: Option<char>,
     }
 
